diff --git a/include/hpp/manipulation/fwd.hh b/include/hpp/manipulation/fwd.hh
index 0455dbef8bd912788205e1e883b52357e1a1ffd8..a6f2509bb45a5ae9ea75dd2676be6c1d6fb3e570 100644
--- a/include/hpp/manipulation/fwd.hh
+++ b/include/hpp/manipulation/fwd.hh
@@ -100,7 +100,8 @@ namespace hpp {
     typedef std::map <DifferentiableFunctionPtr_t, GraspPtr_t> GraspsMap_t;
 
     typedef fcl::TriangleP Triangle;
-    typedef std::list <Triangle> TriangleList;
+    typedef std::pair <JointPtr_t, Triangle> JointAndTriangle_t;
+    typedef std::list <JointAndTriangle_t> JointAndTriangles_t;
   } // namespace manipulation
 } // namespace hpp
 
diff --git a/include/hpp/manipulation/problem-solver.hh b/include/hpp/manipulation/problem-solver.hh
index 45edd5386612f58430f6b8311f5c7becd2ef40ec..3d7466c94dd6e4646cd00cd0601373256901fff6 100644
--- a/include/hpp/manipulation/problem-solver.hh
+++ b/include/hpp/manipulation/problem-solver.hh
@@ -30,7 +30,7 @@
 namespace hpp {
   namespace manipulation {
     class HPP_MANIPULATION_DLLAPI ProblemSolver : public core::ProblemSolver,
-    public Container <LockedJointPtr_t>, public Container <TriangleList>
+    public Container <LockedJointPtr_t>, public Container <JointAndTriangles_t>
     {
       public:
         typedef core::ProblemSolver parent_t;
diff --git a/include/hpp/manipulation/device.hh b/include/hpp/manipulation/device.hh
index e1848911f6e4c447551f71ac8fadb2611f4e2ce7..d8443de483acf3b801d63bc2c86e95811e24cc0f 100644
--- a/include/hpp/manipulation/device.hh
+++ b/include/hpp/manipulation/device.hh
@@ -33,10 +33,10 @@ namespace hpp {
     /// As a deriving class of hpp::model::HumanoidRobot,
     /// it is compatible with hpp::model::urdf::loadHumanoidRobot
     ///
     /// This class also contains model::Gripper, Handle and \ref TriangleList
     class HPP_MANIPULATION_DLLAPI Device : public model::HumanoidRobot,
       public Container <HandlePtr_t>, public Container <model::GripperPtr_t>,
-      public Container <TriangleList>
+      public Container <JointAndTriangles_t>
     {
       public:
         typedef model::HumanoidRobot Parent_t;
@@ -56,7 +56,7 @@ namespace hpp {
 
         /// \name Accessors to container elements
         /// Contained elements are of type model::Gripper, Handle and
-        /// \ref TriangleList
+        /// \ref JointAndTriangles_t
         /// \{
 
         /// Get an element of a container
@@ -33,10 +33,10 @@ namespace hpp {
     /// it is compatible with hpp::model::urdf::loadHumanoidRobot
     ///
-    /// This class also contains model::Gripper, Handle and \ref TriangleList
+    /// This class also contains model::Gripper, Handle and \ref JointAndTriangles_t
     class HPP_MANIPULATION_DLLAPI Device : public model::HumanoidRobot,
       public Container <HandlePtr_t>, public Container <model::GripperPtr_t>,